@@ -12,7 +12,6 @@
 #include <Akri_Element_Cutter.hpp>
 #include <Akri_Element_Intersections.hpp>
 #include <Akri_ElementCutterUtils.hpp>
-#include <Akri_LevelSet.hpp>
 #include <Akri_LevelSetInterfaceGeometry.hpp>
 #include <Akri_MathUtil.hpp>
 #include <Akri_MeshHelpers.hpp>
@@ -69,6 +68,17 @@ std::unique_ptr<Element_Cutter> create_element_cutter_with_error_handling(const
   return cutter;
 }
 
+static stk::math::Vector3d get_centroid(const std::vector<stk::math::Vector3d> & elemNodesCoords)
+{
+  stk::math::Vector3d centroid = stk::math::Vector3d::ZERO;
+  for(auto && nodeCoords : elemNodesCoords)
+  {
+    centroid += nodeCoords;
+  }
+  centroid *= 1./elemNodesCoords.size();
+  return centroid;
+}
+
 LevelSetElementCutter::LevelSetElementCutter(const stk::mesh::BulkData & mesh,
     stk::mesh::Entity element,
     const ParentEdgeMap & parentEdges,
@@ -79,6 +89,20 @@ LevelSetElementCutter::LevelSetElementCutter(const stk::mesh::BulkData & mesh,
   myElementInterfaceCutter = create_element_cutter_with_error_handling(mesh, element, myParentEdges, myParentEdgesAreOrientedSameAsElementEdges, phaseSupport, intersectingPlanesDiagonalPicker);
 }
 
+int LevelSetElementCutter::interface_sign_for_uncrossed_element(const InterfaceID interface, const std::vector<stk::math::Vector3d> & elemNodesCoords) const
+{
+  return myElementInterfaceCutter->sign_at_position(interface, get_centroid(elemNodesCoords));
+}
+
+std::pair<int, double> LevelSetElementCutter::interface_edge_crossing_sign_and_position(const InterfaceID interface, const std::array<stk::math::Vector3d,2> & edgeNodeCoords) const
+{
+  const double sign0 = myElementInterfaceCutter->sign_at_position(interface, edgeNodeCoords[0]);
+  const double sign1 = myElementInterfaceCutter->sign_at_position(interface, edgeNodeCoords[1]);
+  if (sign0 == -sign1)
+    return {sign1, myElementInterfaceCutter->interface_crossing_position(interface, edgeNodeCoords)};
+  return {0, -1.};
+}
+
 std::string LevelSetElementCutter::visualize(const stk::mesh::BulkData & mesh) const
 {
   std::ostringstream os;
@@ -284,17 +308,6 @@ static int get_interface_index(const std::vector<InterfaceID> & sortedInterfaces
   return std::distance(sortedInterfaces.begin(), iter);
 }
 
-static stk::math::Vector3d get_centroid(const std::vector<stk::math::Vector3d> & elemNodesCoords)
-{
-  stk::math::Vector3d centroid = stk::math::Vector3d::ZERO;
-  for(auto && nodeCoords : elemNodesCoords)
-  {
-    centroid += nodeCoords;
-  }
-  centroid *= 1./elemNodesCoords.size();
-  return centroid;
-}
-
 std::vector<int>
 LevelSetElementCutter::get_interface_signs_based_on_crossings(const std::vector<stk::math::Vector3d> & elemNodesCoords,
     const std::vector<const std::vector<int> *> & elemNodesSnappedDomains) const
@@ -516,7 +529,7 @@ void LevelSetInterfaceGeometry::set_parent_element_selector()
     get_active_and_any_levelset_selector(myActivePart, myLSFields);
 }
 
-void LevelSetInterfaceGeometry::prepare_to_process_elements(const stk::mesh::BulkData & mesh,
+void LevelSetInterfaceGeometry::build_parent_edges_for_mesh(const stk::mesh::BulkData & mesh,
     const NodeToCapturedDomainsMap & nodesToCapturedDomains) const
 {
   const bool addHigherOrderMidSideNodes = determine_if_mesh_has_higher_order_midside_nodes_with_level_set_locally(mesh, myPhaseSupport, myLSFields);
@@ -525,7 +538,7 @@ void LevelSetInterfaceGeometry::prepare_to_process_elements(const stk::mesh::Bul
   myParentEdges = build_parent_edges(mesh, myParentsToChildMapper, shouldLinearizeEdges, myParentElementSelector, myPhaseSupport, myLSFields);
 }
 
-void LevelSetInterfaceGeometry::prepare_to_process_elements(const stk::mesh::BulkData & mesh,
+void LevelSetInterfaceGeometry::build_parent_edges_for_elements(const stk::mesh::BulkData & mesh,
     const std::vector<stk::mesh::Entity> & elementsToIntersect,
     const NodeToCapturedDomainsMap & nodesToCapturedDomains) const
 {
@@ -535,6 +548,25 @@ void LevelSetInterfaceGeometry::prepare_to_process_elements(const stk::mesh::Bul
   myParentEdges = build_parent_edges_using_elements(mesh, myParentsToChildMapper, shouldLinearizeEdges, elementsToIntersect, myParentElementSelector, myPhaseSupport, myLSFields);
 }
 
+void LevelSetInterfaceGeometry::prepare_to_decompose_elements(const stk::mesh::BulkData & mesh,
+    const NodeToCapturedDomainsMap & nodesToCapturedDomains) const
+{
+  build_parent_edges_for_mesh(mesh, nodesToCapturedDomains);
+}
+
+void LevelSetInterfaceGeometry::prepare_to_intersect_elements(const stk::mesh::BulkData & mesh,
+    const NodeToCapturedDomainsMap & nodesToCapturedDomains) const
+{
+  build_parent_edges_for_mesh(mesh, nodesToCapturedDomains);
+}
+
+void LevelSetInterfaceGeometry::prepare_to_intersect_elements(const stk::mesh::BulkData & mesh,
+    const std::vector<stk::mesh::Entity> & elementsToIntersect,
+    const NodeToCapturedDomainsMap & nodesToCapturedDomains) const
+{
+  build_parent_edges_for_elements(mesh, elementsToIntersect, nodesToCapturedDomains);
+}
+
 static double compute_edge_length(const stk::mesh::BulkData & mesh, const std::array<stk::mesh::Entity,2> & edgeNodes)
 {
   const int dim = mesh.mesh_meta_data().spatial_dimension();
@@ -574,20 +606,25 @@ static bool element_has_possibly_cut_edge(const stk::mesh::BulkData & mesh, cons
   return false;
 }
 
-std::vector<stk::mesh::Entity> LevelSetInterfaceGeometry::get_possibly_cut_elements(const stk::mesh::BulkData & mesh) const
+std::vector<stk::mesh::Entity> LevelSetInterfaceGeometry::get_active_elements_that_may_be_cut_by_levelsets(const stk::mesh::BulkData & mesh, const stk::mesh::Part & activePart, const std::vector<LS_Field> & LSFields)
 {
   std::vector<stk::mesh::Entity> possibleCutElements;
 
-  const stk::mesh::Selector activeLocallyOwned = myActivePart & mesh.mesh_meta_data().locally_owned_part();
+  const stk::mesh::Selector activeLocallyOwned = activePart & mesh.mesh_meta_data().locally_owned_part();
 
   for(const auto & bucketPtr : mesh.get_buckets(stk::topology::ELEMENT_RANK, activeLocallyOwned))
     for(const auto & elem : *bucketPtr)
-      if (element_has_possibly_cut_edge(mesh, myLSFields, elem))
+      if (element_has_possibly_cut_edge(mesh, LSFields, elem))
         possibleCutElements.push_back(elem);
 
   return possibleCutElements;
 }
 
+std::vector<stk::mesh::Entity> LevelSetInterfaceGeometry::get_possibly_cut_elements(const stk::mesh::BulkData & mesh) const
+{
+  return get_active_elements_that_may_be_cut_by_levelsets(mesh, myActivePart, myLSFields);
+}
+
 static void fill_node_distances(const stk::mesh::BulkData & mesh, const LS_Field & LSField, const stk::mesh::Entity elem, std::vector<double> & nodeDist)
 {
   nodeDist.clear();
@@ -610,21 +647,26 @@ static bool element_intersects_interval(const stk::mesh::BulkData & mesh, const
   return false;
 }
 
-std::vector<stk::mesh::Entity> LevelSetInterfaceGeometry::get_elements_that_intersect_interval(const stk::mesh::BulkData & mesh, const std::array<double,2> loAndHi) const
+std::vector<stk::mesh::Entity> LevelSetInterfaceGeometry::get_active_elements_that_intersect_levelset_interval(const stk::mesh::BulkData & mesh, const stk::mesh::Part & activePart, const std::vector<LS_Field> & LSFields, const std::array<double,2> loAndHi)
 {
   std::vector<stk::mesh::Entity> elementsThaIntersectInterval;
   std::vector<double> elementNodeDist;
 
-  const stk::mesh::Selector activeLocallyOwned = myActivePart & mesh.mesh_meta_data().locally_owned_part();
+  const stk::mesh::Selector activeLocallyOwned = activePart & mesh.mesh_meta_data().locally_owned_part();
 
   for(const auto & bucketPtr : mesh.get_buckets(stk::topology::ELEMENT_RANK, activeLocallyOwned))
     for(const auto & elem : *bucketPtr)
-      if (element_intersects_interval(mesh, myLSFields, elem, loAndHi, elementNodeDist))
+      if (element_intersects_interval(mesh, LSFields, elem, loAndHi, elementNodeDist))
         elementsThaIntersectInterval.push_back(elem);
 
   return elementsThaIntersectInterval;
 }
 
+std::vector<stk::mesh::Entity> LevelSetInterfaceGeometry::get_elements_that_intersect_interval(const stk::mesh::BulkData & mesh, const std::array<double,2> loAndHi) const
+{
+  return get_active_elements_that_intersect_levelset_interval(mesh, myActivePart, myLSFields, loAndHi);
+}
+
 bool LevelSetInterfaceGeometry::have_enough_levelsets_to_have_interior_intersections_or_multiple_crossings() const
 {
   const unsigned minNumLSForInteriorIntersectionsOrMultipleElementCrossings = myPhaseSupport.has_one_levelset_per_phase() ? 3 : 2;
@@ -640,7 +682,7 @@ std::vector<IntersectionPoint> LevelSetInterfaceGeometry::get_edge_intersection_
     const NodeToCapturedDomainsMap & nodesToCapturedDomains) const
 {
   std::vector<IntersectionPoint> intersectionPoints;
-  prepare_to_process_elements(mesh, nodesToCapturedDomains);
+  prepare_to_intersect_elements(mesh, nodesToCapturedDomains);
   const IntersectionPointFilter intersectionPointFilter = keep_all_intersection_points_filter();
   append_intersection_points_from_all_parent_edges(intersectionPoints, myParentEdges, intersectionPointFilter);
   return intersectionPoints;
@@ -652,7 +694,7 @@ void LevelSetInterfaceGeometry::append_element_intersection_points(const stk::me
     const IntersectionPointFilter & intersectionPointFilter,
     std::vector<IntersectionPoint> & intersectionPoints) const
 {
-  prepare_to_process_elements(mesh, elementsToIntersect, nodesToCapturedDomains);
+  prepare_to_intersect_elements(mesh, elementsToIntersect, nodesToCapturedDomains);
   append_intersection_points_from_owned_parent_edges(mesh, myParentElementSelector, intersectionPoints, myParentEdges, intersectionPointFilter);
   if (have_enough_levelsets_to_have_interior_intersections_or_multiple_crossings())
   {
