@@ -149,7 +149,7 @@ void TrustRegionSPGAlgorithm<Real>::initialize(Vector<Real>          &x,
   state_->value = obj.value(x,ftol); 
   state_->nfval++;
   //obj.gradient(*state_->gradientVec,x,ftol);
-  state_->gnorm = computeGradient(x,*state_->gradientVec,*state_->stepVec,state_->searchSize,obj,outStream);
+  computeGradient(x,*state_->gradientVec,*state_->stepVec,state_->searchSize,obj,true,gtol_,state_->gnorm,outStream);
   state_->ngrad++;
   //state_->stepVec->set(x);
   //state_->stepVec->axpy(-one,state_->gradientVec->dual());
@@ -188,30 +188,34 @@ Real TrustRegionSPGAlgorithm<Real>::computeValue(Real inTol,
 }
 
 template<typename Real>
-Real TrustRegionSPGAlgorithm<Real>::computeGradient(const Vector<Real> &x,
+void TrustRegionSPGAlgorithm<Real>::computeGradient(const Vector<Real> &x,
                                                     Vector<Real> &g,
                                                     Vector<Real> &pwa,
                                                     Real del,
                                                     Objective<Real> &obj,
+                                                    bool accept,
+                                                    Real &gtol,
+                                                    Real &gnorm,
                                                     std::ostream &outStream) const {
-  Real gnorm(0);
   if ( useInexact_[1] ) {
     const Real one(1);
-    Real gtol1 = scale0_*del;
-    Real gtol0 = gtol1 + one;
-    while ( gtol0 > gtol1 ) {
-      obj.gradient(g,x,gtol1);
+    Real gtol0 = scale0_*del;
+    if (accept) gtol  = gtol0 + one;
+    else        gtol0 = scale0_*std::min(gnorm,del);
+    while ( gtol > gtol0 ) {
+      gtol = gtol0;
+      obj.gradient(g,x,gtol);
       gnorm = TypeB::Algorithm<Real>::optimalityCriterion(x,g,pwa,outStream);
-      gtol0 = gtol1;
-      gtol1 = scale0_*std::min(gnorm,del);
+      gtol0 = scale0_*std::min(gnorm,del);
     }
   }
   else {
-    Real gtol = std::sqrt(ROL_EPSILON<Real>());
-    obj.gradient(g,x,gtol);
-    gnorm = TypeB::Algorithm<Real>::optimalityCriterion(x,g,pwa,outStream);
+    if (accept) {
+      gtol = std::sqrt(ROL_EPSILON<Real>());
+      obj.gradient(g,x,gtol);
+      gnorm = TypeB::Algorithm<Real>::optimalityCriterion(x,g,pwa,outStream);
+    }
   }
-  return gnorm;
 }
 
 template<typename Real>
@@ -244,7 +248,7 @@ void TrustRegionSPGAlgorithm<Real>::run(Vector<Real>          &x,
 
   while (status_->check(*state_)) {
     // Build trust-region model
-    model_->setData(obj,*state_->iterateVec,*state_->gradientVec);
+    model_->setData(obj,*state_->iterateVec,*state_->gradientVec,gtol_);
 
     /**** SOLVE TRUST-REGION SUBPROBLEM ****/
     q = zero;
@@ -300,6 +304,7 @@ void TrustRegionSPGAlgorithm<Real>::run(Vector<Real>          &x,
       else { // Shrink trust-region radius
         state_->searchSize = gamma1_*std::min(state_->snorm,state_->searchSize);
       }
+      computeGradient(x,*state_->gradientVec,*pwa1,state_->searchSize,obj,false,gtol_,state_->gnorm,outStream);
     }
     else if ((rho >= eta0_ && TRflag_ != TRUtils::NPOSPREDNEG)
              || (TRflag_ == TRUtils::POSPREDNEG)) { // Step Accepted
@@ -319,7 +324,7 @@ void TrustRegionSPGAlgorithm<Real>::run(Vector<Real>          &x,
       if (rho >= eta2_) state_->searchSize = std::min(gamma2_*state_->searchSize, delMax_);
       // Compute gradient at new iterate
       dwa1->set(*state_->gradientVec);
-      state_->gnorm = computeGradient(x,*state_->gradientVec,*pwa1,state_->searchSize,obj,outStream);
+      computeGradient(x,*state_->gradientVec,*pwa1,state_->searchSize,obj,true,gtol_,state_->gnorm,outStream);
       state_->ngrad++;
       state_->iterateVec->set(x);
       // Update secant information in trust-region model
