@@ -301,7 +301,8 @@ std::string BalanceSettings::getOutputSubdomainFieldName() const
 
 std::string BalanceSettings::getDiagnosticElementWeightFieldName() const
 {
-  return "stk_balance_diagnostic_element_weight";
+
+  return "stk_balance_diagnostic_element_weight" + std::to_string(getNumCriteria());
 }
 
 std::string BalanceSettings::getVertexConnectivityWeightFieldName() const
@@ -326,7 +327,8 @@ const stk::mesh::Field<int> * BalanceSettings::getOutputSubdomainField(const stk
 
 const stk::mesh::Field<double> * BalanceSettings::getDiagnosticElementWeightField(const stk::mesh::BulkData & stkMeshBulkData) const
 {
-  if (m_diagnosticElementWeightsField == nullptr) {
+  if (m_diagnosticElementWeightsField == nullptr ||
+      (getDiagnosticElementWeightFieldName() != m_diagnosticElementWeightsField->name())) {
     m_diagnosticElementWeightsField =
         stkMeshBulkData.mesh_meta_data().get_field<double>(stk::topology::ELEM_RANK,
                                                            getDiagnosticElementWeightFieldName());
@@ -503,46 +505,74 @@ int GraphCreationSettings::getGraphVertexWeight(stk::topology type) const
   switch(type)
   {
   case stk::topology::PARTICLE:
-  case stk::topology::LINE_2:
+  case stk::topology::LINE_2_1D:
+  case stk::topology::LINE_3_1D:
   case stk::topology::BEAM_2:
   case stk::topology::BEAM_3:
+  case stk::topology::SHELL_LINE_2:
+  case stk::topology::SHELL_LINE_3:
   case stk::topology::SPRING_2:
   case stk::topology::SPRING_3:
     return 1;
-  case stk::topology::SHELL_TRIANGLE_3:
-    return 3;
-  case stk::topology::SHELL_TRIANGLE_6:
-    return 8;
-  case stk::topology::SHELL_QUADRILATERAL_4:
-    return 6;
-  case stk::topology::SHELL_QUADRILATERAL_8:
-    return 8;
   case stk::topology::TRI_3_2D:
     return 3;
+  case stk::topology::TRI_4_2D:
+    return 4;
+  case stk::topology::TRI_6_2D:
+    return 6;
   case stk::topology::QUAD_4_2D:
     return 6;
-  case stk::topology::HEXAHEDRON_8:
-    return 3;
-  case stk::topology::HEXAHEDRON_20:
+  case stk::topology::QUAD_8_2D:
     return 8;
+  case stk::topology::QUAD_9_2D:
+    return 9;
+  case stk::topology::SHELL_TRI_3:
+    return 3;
+  case stk::topology::SHELL_TRI_4:
+    return 4;
+  case stk::topology::SHELL_TRI_6:
+    return 8;
+  case stk::topology::SHELL_QUAD_4:
+    return 6;
+  case stk::topology::SHELL_QUAD_8:
+    return 8;
+  case stk::topology::SHELL_QUAD_9:
+    return 9;
+  case stk::topology::TET_4:
+    return 1;
+  case stk::topology::TET_8:
+    return 5;
+  case stk::topology::TET_10:
+    return 6;
+  case stk::topology::TET_11:
+    return 7;
   case stk::topology::PYRAMID_5:
     return 1;
-  case stk::topology::TETRAHEDRON_4:
-    return 1;
-  case stk::topology::TETRAHEDRON_10:
+  case stk::topology::PYRAMID_13:
+    return 5;
+  case stk::topology::PYRAMID_14:
     return 6;
   case stk::topology::WEDGE_6:
     return 2;
   case stk::topology::WEDGE_12:
-    // TODO
+    return 10;
   case stk::topology::WEDGE_15:
     return 12;
+  case stk::topology::WEDGE_18:
+    return 14;
+  case stk::topology::HEX_8:
+    return 3;
+  case stk::topology::HEX_20:
+    return 8;
+  case stk::topology::HEX_27:
+    return 10;
   default:
     if ( type.is_superelement( ))
     {
       return 10;
     }
-    throw("Invalid Element Type In WeightsOfElement");
+    STK_ThrowErrorMsg("Unrecognized element type (" << type << ") in getGraphVertexWeight()");
+    return 0;  // Keep compiler happy about always having a return value
   }
 }
 
@@ -673,6 +703,7 @@ int GraphCreationSettings::getConnectionTableIndex(stk::topology elementTopology
   case stk::topology::TET_11:
   case stk::topology::PYRAMID_13:
   case stk::topology::PYRAMID_14:
+  case stk::topology::WEDGE_12:
   case stk::topology::WEDGE_15:
   case stk::topology::WEDGE_18:
   case stk::topology::HEX_20:
@@ -686,8 +717,7 @@ int GraphCreationSettings::getConnectionTableIndex(stk::topology elementTopology
     }
     else
     {
-      std::cerr << "Topology is " << elementTopology << std::endl;
-      throw("Invalid Element Type in GetDimOfElement");
+      STK_ThrowErrorMsg("Unrecognized element type (" << elementTopology << ") in getConnectionTableIndex()");
     }
     break;
   };
@@ -757,8 +787,7 @@ int GraphCreationSettings::getEdgeWeightTableIndex(stk::topology elementTopology
     }
     else
     {
-      std::cerr << "Topology is " << elementTopology << std::endl;
-      throw("Invalid Element Type in GetDimOfElement");
+      STK_ThrowErrorMsg("Unrecognized element type (" << elementTopology << ") in getEdgeWeightTableIndex()");
     }
     break;
   };
