@@ -35,6 +35,7 @@
 #ifndef STK_MESH_BASE_FIELDBLAS_HPP
 #define STK_MESH_BASE_FIELDBLAS_HPP
 
+#include <stk_util/stk_config.h>
 #include <stk_mesh/base/Entity.hpp>
 #include <stk_mesh/base/Bucket.hpp>
 #include <stk_mesh/base/Selector.hpp>
@@ -42,6 +43,8 @@
 #include <stk_mesh/base/Field.hpp>
 #include <stk_util/parallel/ParallelReduce.hpp>
 #include <stk_mesh/base/MetaData.hpp>
+#include <stk_mesh/base/Ngp.hpp>
+#include <stk_mesh/base/GetNgpField.hpp>
 
 #include <complex>
 #include <string>
@@ -552,17 +555,40 @@ void INTERNAL_field_copy(const FieldBase& xField, const FieldBase& yField, const
 {
   BucketVector const& buckets = xField.get_mesh().get_buckets(xField.entity_rank(), selector);
 
-  int orig_thread_count = fix_omp_threads();
+#ifdef STK_USE_DEVICE_MESH
+  const bool alreadySyncd_or_HostNewest = !xField.need_sync_to_host();
+
+  yField.clear_sync_state();
+
+  if (alreadySyncd_or_HostNewest) {
+#endif
+
+    int orig_thread_count = fix_omp_threads();
 #ifdef OPEN_MP_ACTIVE_FIELDBLAS_HPP
 #pragma omp parallel for schedule(static)
 #endif
-  for (size_t i = 0; i < buckets.size(); ++i) {
-      Bucket & b = *buckets[i];
-      BucketSpan<Scalar> x(xField, b);
-      BucketSpan<Scalar> y(yField, b);
-      y = x;
+    for (size_t i = 0; i < buckets.size(); ++i) {
+        Bucket & b = *buckets[i];
+        BucketSpan<Scalar> x(xField, b);
+        BucketSpan<Scalar> y(yField, b);
+        y = x;
+    }
+    unfix_omp_threads(orig_thread_count);
+    yField.clear_sync_state();
+    yField.modify_on_host();
+#ifdef STK_USE_DEVICE_MESH
   }
-  unfix_omp_threads(orig_thread_count);
+  else { // copy on device
+    auto ngpX = stk::mesh::get_updated_ngp_field<Scalar>(xField);
+    auto ngpY = stk::mesh::get_updated_ngp_field<Scalar>(yField);
+    auto ngpXview = impl::get_device_data(ngpX);
+    auto ngpYview = impl::get_device_data(ngpY);
+
+    Kokkos::deep_copy(ngpYview, ngpXview);
+    yField.modify_on_device();
+  }
+
+#endif
 }
 
 inline
