@@ -14,12 +14,12 @@
 
 namespace Tempus {
 
-  TEMPUS_INSTANTIATE_TEMPLATE_CLASS(TimeEventRange)
+TEMPUS_INSTANTIATE_TEMPLATE_CLASS(TimeEventRange)
 
-  // Nonmember constructor
-  template Teuchos::RCP<TimeEventRange<double> >
-  createTimeEventRange(Teuchos::RCP<Teuchos::ParameterList> pl);
+// Nonmember constructor
+template Teuchos::RCP<TimeEventRange<double> > createTimeEventRange(
+    Teuchos::RCP<Teuchos::ParameterList> pl);
 
-} // namespace Tempus
+}  // namespace Tempus
 
 #endif
