@@ -16,17 +16,15 @@
 #include "Tempus_StepperBDF2ModifierXBase.hpp"
 #include "Tempus_StepperBDF2ModifierDefault.hpp"
 
-
 namespace Tempus_Unit_Test {
 
+using Teuchos::ParameterList;
 using Teuchos::RCP;
 using Teuchos::rcp;
 using Teuchos::rcp_const_cast;
 using Teuchos::rcp_dynamic_cast;
-using Teuchos::ParameterList;
 using Teuchos::sublist;
 
-
 // ************************************************************
 // ************************************************************
 TEUCHOS_UNIT_TEST(BDF2, Default_Construction)
@@ -39,39 +37,53 @@ TEUCHOS_UNIT_TEST(BDF2, Default_Construction)
   stepper->initialize();
   TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
 
-
   // Default values for construction.
   auto modifier = rcp(new Tempus::StepperBDF2ModifierDefault<double>());
-  auto solver = rcp(new Thyra::NOXNonlinearSolver());
+  auto solver   = rcp(new Thyra::NOXNonlinearSolver());
   solver->setParameterList(Tempus::defaultSolverParameters());
 
   auto startUpStepper = rcp(new Tempus::StepperDIRK_1StageTheta<double>());
-  startUpStepper->setModel(model);  // Can use the same model since both steppers are implicit ODEs.
+  startUpStepper->setModel(
+      model);  // Can use the same model since both steppers are implicit ODEs.
   startUpStepper->initialize();
 
-  auto defaultStepper = rcp(new Tempus::StepperBDF2<double>());
+  auto defaultStepper       = rcp(new Tempus::StepperBDF2<double>());
   bool useFSAL              = defaultStepper->getUseFSAL();
   std::string ICConsistency = defaultStepper->getICConsistency();
   bool ICConsistencyCheck   = defaultStepper->getICConsistencyCheck();
   bool zeroInitialGuess     = defaultStepper->getZeroInitialGuess();
 
   // Test the set functions.
-  stepper->setAppAction(modifier);                     stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
-  stepper->setSolver(solver);                          stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
-  stepper->setStartUpStepper(startUpStepper);          stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
-  stepper->setUseFSAL(useFSAL);                        stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
-  stepper->setICConsistency(ICConsistency);            stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
-  stepper->setICConsistencyCheck(ICConsistencyCheck);  stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
-  stepper->setZeroInitialGuess(zeroInitialGuess);      stepper->initialize();  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setAppAction(modifier);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setSolver(solver);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setStartUpStepper(startUpStepper);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setUseFSAL(useFSAL);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setICConsistency(ICConsistency);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setICConsistencyCheck(ICConsistencyCheck);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
+  stepper->setZeroInitialGuess(zeroInitialGuess);
+  stepper->initialize();
+  TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
 
-  stepper = rcp(new Tempus::StepperBDF2<double>(model, solver, startUpStepper, useFSAL,
-            ICConsistency, ICConsistencyCheck, zeroInitialGuess,modifier));
+  stepper = rcp(new Tempus::StepperBDF2<double>(
+      model, solver, startUpStepper, useFSAL, ICConsistency, ICConsistencyCheck,
+      zeroInitialGuess, modifier));
   TEUCHOS_TEST_FOR_EXCEPT(!stepper->isInitialized());
   // Test stepper properties.
   TEUCHOS_ASSERT(stepper->getOrder() == 2);
 }
 
-
 // ************************************************************
 // ************************************************************
 TEUCHOS_UNIT_TEST(BDF2, StepperFactory_Construction)
@@ -80,34 +92,35 @@ TEUCHOS_UNIT_TEST(BDF2, StepperFactory_Construction)
   testFactoryConstruction("BDF2", model);
 }
 
-
 // ************************************************************
 // ************************************************************
 TEUCHOS_UNIT_TEST(BDF2, ParameterList)
 {
   // Read params from .xml file
   RCP<ParameterList> pList =
-    Teuchos::getParametersFromXmlFile("Tempus_BDF2_SinCos.xml");
+      Teuchos::getParametersFromXmlFile("Tempus_BDF2_SinCos.xml");
 
   // Setup the SinCosModel
   RCP<ParameterList> scm_pl = sublist(pList, "SinCosModel", true);
-  auto model = rcp(new Tempus_Test::SinCosModel<double> (scm_pl));
+  auto model                = rcp(new Tempus_Test::SinCosModel<double>(scm_pl));
 
-  RCP<ParameterList> tempusPL  = sublist(pList, "Tempus", true);
+  RCP<ParameterList> tempusPL = sublist(pList, "Tempus", true);
 
   // Test constructor IntegratorBasic(tempusPL, model)
   {
     RCP<Tempus::IntegratorBasic<double> > integrator =
-      Tempus::createIntegratorBasic<double>(tempusPL, model);
+        Tempus::createIntegratorBasic<double>(tempusPL, model);
 
     RCP<ParameterList> stepperPL = sublist(tempusPL, "Default Stepper", true);
     RCP<const ParameterList> defaultPL =
-      integrator->getStepper()->getValidParameters();
+        integrator->getStepper()->getValidParameters();
     bool pass = haveSameValuesSorted(*stepperPL, *defaultPL, true);
     if (!pass) {
       out << std::endl;
-      out << "stepperPL -------------- \n" << *stepperPL << std::endl;
-      out << "defaultPL -------------- \n" << *defaultPL << std::endl;
+      out << "stepperPL -------------- \n"
+          << *stepperPL << std::endl;
+      out << "defaultPL -------------- \n"
+          << *defaultPL << std::endl;
     }
     TEST_ASSERT(pass)
   }
@@ -115,23 +128,24 @@ TEUCHOS_UNIT_TEST(BDF2, ParameterList)
   // Test constructor IntegratorBasic(model, stepperType)
   {
     RCP<Tempus::IntegratorBasic<double> > integrator =
-      Tempus::createIntegratorBasic<double>(model, std::string("BDF2"));
+        Tempus::createIntegratorBasic<double>(model, std::string("BDF2"));
 
     RCP<ParameterList> stepperPL = sublist(tempusPL, "Default Stepper", true);
     RCP<const ParameterList> defaultPL =
-      integrator->getStepper()->getValidParameters();
+        integrator->getStepper()->getValidParameters();
 
     bool pass = haveSameValuesSorted(*stepperPL, *defaultPL, true);
     if (!pass) {
       out << std::endl;
-      out << "stepperPL -------------- \n" << *stepperPL << std::endl;
-      out << "defaultPL -------------- \n" << *defaultPL << std::endl;
+      out << "stepperPL -------------- \n"
+          << *stepperPL << std::endl;
+      out << "defaultPL -------------- \n"
+          << *defaultPL << std::endl;
     }
     TEST_ASSERT(pass)
   }
 }
 
-
 // ************************************************************
 // ************************************************************
 TEUCHOS_UNIT_TEST(BDF2, ConstructingFromDefaults)
@@ -141,22 +155,21 @@ TEUCHOS_UNIT_TEST(BDF2, ConstructingFromDefaults)
   options.push_back("Default Parameters");
   options.push_back("ICConsistency and Check");
 
-  for(const auto& option: options) {
-
+  for (const auto& option : options) {
     // Read params from .xml file
     RCP<ParameterList> pList =
-      Teuchos::getParametersFromXmlFile("Tempus_BDF2_SinCos.xml");
+        Teuchos::getParametersFromXmlFile("Tempus_BDF2_SinCos.xml");
     RCP<ParameterList> pl = sublist(pList, "Tempus", true);
 
     // Setup the SinCosModel
     RCP<ParameterList> scm_pl = sublist(pList, "SinCosModel", true);
-    //RCP<SinCosModel<double> > model = sineCosineModel(scm_pl);
+    // RCP<SinCosModel<double> > model = sineCosineModel(scm_pl);
     auto model = rcp(new Tempus_Test::SinCosModel<double>(scm_pl));
 
     // Setup Stepper for field solve ----------------------------
     auto stepper = rcp(new Tempus::StepperBDF2<double>());
     stepper->setModel(model);
-    if ( option == "ICConsistency and Check") {
+    if (option == "ICConsistency and Check") {
       stepper->setICConsistency("Consistent");
       stepper->setICConsistencyCheck(true);
     }
@@ -164,22 +177,23 @@ TEUCHOS_UNIT_TEST(BDF2, ConstructingFromDefaults)
 
     // Setup TimeStepControl ------------------------------------
     auto timeStepControl = rcp(new Tempus::TimeStepControl<double>());
-    ParameterList tscPL = pl->sublist("Default Integrator")
-                             .sublist("Time Step Control");
-    timeStepControl->setInitIndex(tscPL.get<int>   ("Initial Time Index"));
-    timeStepControl->setInitTime (tscPL.get<double>("Initial Time"));
+    ParameterList tscPL =
+        pl->sublist("Default Integrator").sublist("Time Step Control");
+    timeStepControl->setInitIndex(tscPL.get<int>("Initial Time Index"));
+    timeStepControl->setInitTime(tscPL.get<double>("Initial Time"));
     timeStepControl->setFinalTime(tscPL.get<double>("Final Time"));
     timeStepControl->setInitTimeStep(dt);
     timeStepControl->initialize();
 
     // Setup initial condition SolutionState --------------------
     auto inArgsIC = model->getNominalValues();
-    auto icSolution = rcp_const_cast<Thyra::VectorBase<double> > (inArgsIC.get_x());
+    auto icSolution =
+        rcp_const_cast<Thyra::VectorBase<double> >(inArgsIC.get_x());
     auto icState = Tempus::createSolutionStateX(icSolution);
-    icState->setTime    (timeStepControl->getInitTime());
-    icState->setIndex   (timeStepControl->getInitIndex());
+    icState->setTime(timeStepControl->getInitTime());
+    icState->setIndex(timeStepControl->getInitIndex());
     icState->setTimeStep(0.0);
-    icState->setOrder   (stepper->getOrder());
+    icState->setOrder(stepper->getOrder());
     icState->setSolutionStatus(Tempus::Status::PASSED);  // ICs are passing.
 
     // Setup SolutionHistory ------------------------------------
@@ -194,105 +208,104 @@ TEUCHOS_UNIT_TEST(BDF2, ConstructingFromDefaults)
 
     // Setup Integrator -----------------------------------------
     RCP<Tempus::IntegratorBasic<double> > integrator =
-      Tempus::createIntegratorBasic<double>();
+        Tempus::createIntegratorBasic<double>();
     integrator->setStepper(stepper);
     integrator->setTimeStepControl(timeStepControl);
     integrator->setSolutionHistory(solutionHistory);
-    //integrator->setObserver(...);
+    // integrator->setObserver(...);
     integrator->initialize();
 
-
     // Integrate to timeMax
     bool integratorStatus = integrator->advanceTime();
     TEST_ASSERT(integratorStatus)
 
-
     // Test if at 'Final Time'
-    double time = integrator->getTime();
-    double timeFinal =pl->sublist("Default Integrator")
-       .sublist("Time Step Control").get<double>("Final Time");
+    double time      = integrator->getTime();
+    double timeFinal = pl->sublist("Default Integrator")
+                           .sublist("Time Step Control")
+                           .get<double>("Final Time");
     TEST_FLOATING_EQUALITY(time, timeFinal, 1.0e-14);
 
     // Time-integrated solution and the exact solution
     RCP<Thyra::VectorBase<double> > x = integrator->getX();
     RCP<const Thyra::VectorBase<double> > x_exact =
-      model->getExactSolution(time).get_x();
+        model->getExactSolution(time).get_x();
 
     // Calculate the error
     RCP<Thyra::VectorBase<double> > xdiff = x->clone_v();
     Thyra::V_StVpStV(xdiff.ptr(), 1.0, *x_exact, -1.0, *(x));
 
     // Check the order and intercept
-    out << "  Stepper = " << stepper->description()
-        << "\n            with " << option << std::endl;
+    out << "  Stepper = " << stepper->description() << "\n            with "
+        << option << std::endl;
     out << "  =========================" << std::endl;
     out << "  Exact solution   : " << get_ele(*(x_exact), 0) << "   "
-                                   << get_ele(*(x_exact), 1) << std::endl;
-    out << "  Computed solution: " << get_ele(*(x      ), 0) << "   "
-                                   << get_ele(*(x      ), 1) << std::endl;
-    out << "  Difference       : " << get_ele(*(xdiff  ), 0) << "   "
-                                   << get_ele(*(xdiff  ), 1) << std::endl;
+        << get_ele(*(x_exact), 1) << std::endl;
+    out << "  Computed solution: " << get_ele(*(x), 0) << "   "
+        << get_ele(*(x), 1) << std::endl;
+    out << "  Difference       : " << get_ele(*(xdiff), 0) << "   "
+        << get_ele(*(xdiff), 1) << std::endl;
     out << "  =========================" << std::endl;
-    TEST_FLOATING_EQUALITY(get_ele(*(x), 0), 0.839732, 1.0e-4 );
-    TEST_FLOATING_EQUALITY(get_ele(*(x), 1), 0.542663, 1.0e-4 );
+    TEST_FLOATING_EQUALITY(get_ele(*(x), 0), 0.839732, 1.0e-4);
+    TEST_FLOATING_EQUALITY(get_ele(*(x), 1), 0.542663, 1.0e-4);
   }
 }
 
-
 // ************************************************************
 // ************************************************************
 class StepperBDF2ModifierTest
-  : virtual public Tempus::StepperBDF2ModifierBase<double>
-{
-public:
-
+  : virtual public Tempus::StepperBDF2ModifierBase<double> {
+ public:
   /// Constructor
   StepperBDF2ModifierTest()
-    : testBEGIN_STEP(false),testBEFORE_SOLVE(false),
-      testAFTER_SOLVE(false),testEND_STEP(false),
-      testCurrentValue(-0.99), testWorkingValue(-0.99),
-      testDt(.99), testType("")
-  {}
+    : testBEGIN_STEP(false),
+      testBEFORE_SOLVE(false),
+      testAFTER_SOLVE(false),
+      testEND_STEP(false),
+      testCurrentValue(-0.99),
+      testWorkingValue(-0.99),
+      testDt(.99),
+      testType("")
+  {
+  }
 
   /// Destructor
-  virtual ~StepperBDF2ModifierTest(){}
+  virtual ~StepperBDF2ModifierTest() {}
 
   /// Modify BDF2 Stepper at end of takeStep.
-  virtual void modify(Teuchos::RCP<Tempus::SolutionHistory<double> > sh,
-    Teuchos::RCP<Tempus::StepperBDF2<double> > stepper,
-    const typename Tempus::StepperBDF2AppAction<double>::ACTION_LOCATION actLoc)
+  virtual void modify(
+      Teuchos::RCP<Tempus::SolutionHistory<double> > sh,
+      Teuchos::RCP<Tempus::StepperBDF2<double> > stepper,
+      const typename Tempus::StepperBDF2AppAction<double>::ACTION_LOCATION
+          actLoc)
   {
-    switch(actLoc) {
-    case StepperBDF2AppAction<double>::BEGIN_STEP:
-      {
-        testBEGIN_STEP = true;
-        auto x = sh->getWorkingState()->getX();
+    switch (actLoc) {
+      case StepperBDF2AppAction<double>::BEGIN_STEP: {
+        testBEGIN_STEP   = true;
+        auto x           = sh->getWorkingState()->getX();
         testCurrentValue = get_ele(*(x), 0);
         break;
       }
-    case StepperBDF2AppAction<double>::BEFORE_SOLVE:
-      {
+      case StepperBDF2AppAction<double>::BEFORE_SOLVE: {
         testBEFORE_SOLVE = true;
-        testType = "BDF2 - Modifier";
+        testType         = "BDF2 - Modifier";
         break;
       }
-    case StepperBDF2AppAction<double>::AFTER_SOLVE:
-      {
+      case StepperBDF2AppAction<double>::AFTER_SOLVE: {
         testAFTER_SOLVE = true;
-        testDt = sh->getCurrentState()->getTimeStep()/10.0;
+        testDt          = sh->getCurrentState()->getTimeStep() / 10.0;
         sh->getCurrentState()->setTimeStep(testDt);
         break;
       }
-    case StepperBDF2AppAction<double>::END_STEP:
-      {
-        testEND_STEP = true;
-        auto x  = sh->getWorkingState()->getX();
+      case StepperBDF2AppAction<double>::END_STEP: {
+        testEND_STEP     = true;
+        auto x           = sh->getWorkingState()->getX();
         testWorkingValue = get_ele(*(x), 0);
         break;
       }
-    default:
-      TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error,
-                                 "Error - unknown action location.\n");
+      default:
+        TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error,
+                                   "Error - unknown action location.\n");
     }
   }
   bool testBEGIN_STEP;
@@ -319,18 +332,18 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_Modifier)
   // Setup initial condition SolutionState --------------------
   auto inArgsIC = model->getNominalValues();
   auto icSolution =
-    rcp_const_cast<Thyra::VectorBase<double> > (inArgsIC.get_x());
+      rcp_const_cast<Thyra::VectorBase<double> >(inArgsIC.get_x());
   auto icState = Tempus::createSolutionStateX(icSolution);
-  icState->setTime    (0.0);
-  icState->setIndex   (0);
+  icState->setTime(0.0);
+  icState->setIndex(0);
   icState->setTimeStep(1.0);
-  icState->setOrder   (stepper->getOrder());
+  icState->setOrder(stepper->getOrder());
   icState->setSolutionStatus(Tempus::Status::PASSED);  // ICs are passing.
 
   // Setup TimeStepControl ------------------------------------
   auto timeStepControl = rcp(new Tempus::TimeStepControl<double>());
   timeStepControl->setInitIndex(0);
-  timeStepControl->setInitTime (0.0);
+  timeStepControl->setInitTime(0.0);
   timeStepControl->setFinalTime(2.0);
   timeStepControl->setInitTimeStep(1.0);
   timeStepControl->initialize();
@@ -360,67 +373,67 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_Modifier)
   auto Dt = solutionHistory->getCurrentState()->getTimeStep();
   TEST_FLOATING_EQUALITY(modifier->testDt, Dt, 1.0e-15);
   auto x = solutionHistory->getCurrentState()->getX();
-  TEST_FLOATING_EQUALITY(modifier->testCurrentValue,  get_ele(*(x), 0), 1.0e-15);
+  TEST_FLOATING_EQUALITY(modifier->testCurrentValue, get_ele(*(x), 0), 1.0e-15);
   x = solutionHistory->getWorkingState()->getX();
-  TEST_FLOATING_EQUALITY(modifier->testWorkingValue,  get_ele(*(x), 0), 1.0e-15);
+  TEST_FLOATING_EQUALITY(modifier->testWorkingValue, get_ele(*(x), 0), 1.0e-15);
   TEST_COMPARE(modifier->testType, ==, "BDF2 - Modifier");
 }
 
-
 // ************************************************************
 // ************************************************************
 class StepperBDF2ObserverTest
-  : virtual public Tempus::StepperBDF2ObserverBase<double>
-{
-public:
-
+  : virtual public Tempus::StepperBDF2ObserverBase<double> {
+ public:
   /// Constructor
   StepperBDF2ObserverTest()
-    : testBEGIN_STEP(false),testBEFORE_SOLVE(false),
-      testAFTER_SOLVE(false),testEND_STEP(false),
-      testCurrentValue(0.99), testWorkingValue(0.99),
-      testDt(.99), testType("")
-  {}
+    : testBEGIN_STEP(false),
+      testBEFORE_SOLVE(false),
+      testAFTER_SOLVE(false),
+      testEND_STEP(false),
+      testCurrentValue(0.99),
+      testWorkingValue(0.99),
+      testDt(.99),
+      testType("")
+  {
+  }
 
   /// Destructor
-  virtual ~StepperBDF2ObserverTest(){}
+  virtual ~StepperBDF2ObserverTest() {}
 
   /// Modify BDF2 Stepper at end of takeStep.
-  virtual void modify(Teuchos::RCP<Tempus::SolutionHistory<double> > sh,
-    Teuchos::RCP<Tempus::StepperBDF2<double> > stepper,
-    const typename Tempus::StepperBDF2AppAction<double>::ACTION_LOCATION actLoc)
+  virtual void modify(
+      Teuchos::RCP<Tempus::SolutionHistory<double> > sh,
+      Teuchos::RCP<Tempus::StepperBDF2<double> > stepper,
+      const typename Tempus::StepperBDF2AppAction<double>::ACTION_LOCATION
+          actLoc)
   {
-    switch(actLoc) {
-    case StepperBDF2AppAction<double>::BEGIN_STEP:
-      {
-        testBEGIN_STEP = true;
-        auto x = sh->getCurrentState()->getX();
+    switch (actLoc) {
+      case StepperBDF2AppAction<double>::BEGIN_STEP: {
+        testBEGIN_STEP   = true;
+        auto x           = sh->getCurrentState()->getX();
         testCurrentValue = get_ele(*(x), 0);
         break;
       }
-    case StepperBDF2AppAction<double>::BEFORE_SOLVE:
-      {
+      case StepperBDF2AppAction<double>::BEFORE_SOLVE: {
         testBEFORE_SOLVE = true;
-        testType = stepper->getStepperType();
+        testType         = stepper->getStepperType();
         break;
       }
-    case StepperBDF2AppAction<double>::AFTER_SOLVE:
-      {
+      case StepperBDF2AppAction<double>::AFTER_SOLVE: {
         testAFTER_SOLVE = true;
-        testDt = sh->getCurrentState()->getTimeStep();
+        testDt          = sh->getCurrentState()->getTimeStep();
         break;
       }
-    case StepperBDF2AppAction<double>::END_STEP:
-      {
-        testEND_STEP = true;
-        auto x = sh->getWorkingState()->getX();
+      case StepperBDF2AppAction<double>::END_STEP: {
+        testEND_STEP     = true;
+        auto x           = sh->getWorkingState()->getX();
         testWorkingValue = get_ele(*(x), 0);
         break;
       }
 
-    default:
-      TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error,
-                                 "Error - unknown action location.\n");
+      default:
+        TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error,
+                                   "Error - unknown action location.\n");
     }
   }
   bool testBEGIN_STEP;
@@ -433,7 +446,6 @@ public:
   std::string testType;
 };
 
-
 // ************************************************************
 // ************************************************************
 TEUCHOS_UNIT_TEST(BDF2, AppAction_Observer)
@@ -450,18 +462,18 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_Observer)
   // Setup initial condition SolutionState --------------------
   auto inArgsIC = model->getNominalValues();
   auto icSolution =
-    rcp_const_cast<Thyra::VectorBase<double> > (inArgsIC.get_x());
+      rcp_const_cast<Thyra::VectorBase<double> >(inArgsIC.get_x());
   auto icState = Tempus::createSolutionStateX(icSolution);
-  icState->setTime    (0.0);
-  icState->setIndex   (0);
+  icState->setTime(0.0);
+  icState->setIndex(0);
   icState->setTimeStep(1.0);
-  icState->setOrder   (stepper->getOrder());
+  icState->setOrder(stepper->getOrder());
   icState->setSolutionStatus(Tempus::Status::PASSED);  // ICs are passing.
 
   // Setup TimeStepControl ------------------------------------
   auto timeStepControl = rcp(new Tempus::TimeStepControl<double>());
   timeStepControl->setInitIndex(0);
-  timeStepControl->setInitTime (0.0);
+  timeStepControl->setInitTime(0.0);
   timeStepControl->setFinalTime(2.0);
   timeStepControl->setInitTimeStep(1.0);
   timeStepControl->initialize();
@@ -492,64 +504,64 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_Observer)
   TEST_FLOATING_EQUALITY(observer->testDt, Dt, 1.0e-15);
 
   auto x = solutionHistory->getCurrentState()->getX();
-  TEST_FLOATING_EQUALITY(observer->testCurrentValue,  get_ele(*(x), 0), 1.0e-15);
-  x      = solutionHistory->getWorkingState()->getX();
-  TEST_FLOATING_EQUALITY(observer->testWorkingValue,  get_ele(*(x), 0), 1.0e-15);
+  TEST_FLOATING_EQUALITY(observer->testCurrentValue, get_ele(*(x), 0), 1.0e-15);
+  x = solutionHistory->getWorkingState()->getX();
+  TEST_FLOATING_EQUALITY(observer->testWorkingValue, get_ele(*(x), 0), 1.0e-15);
   TEST_COMPARE(observer->testType, ==, "BDF2 - Modifier");
 }
 
-
 // ************************************************************
 // ************************************************************
 class StepperBDF2ModifierXTest
-  : virtual public Tempus::StepperBDF2ModifierXBase<double>
-{
-public:
-
+  : virtual public Tempus::StepperBDF2ModifierXBase<double> {
+ public:
   /// Constructor
   StepperBDF2ModifierXTest()
-    : testX_BEGIN_STEP(false),testX_BEFORE_SOLVE(false),
-      testX_AFTER_SOLVE(false),testX_END_STEP(false),
-      testXbegin(-.99),testXend(-.99),testTime(0.0),testDt(0.0)
-  {}
+    : testX_BEGIN_STEP(false),
+      testX_BEFORE_SOLVE(false),
+      testX_AFTER_SOLVE(false),
+      testX_END_STEP(false),
+      testXbegin(-.99),
+      testXend(-.99),
+      testTime(0.0),
+      testDt(0.0)
+  {
+  }
 
   /// Destructor
-  virtual ~StepperBDF2ModifierXTest(){}
+  virtual ~StepperBDF2ModifierXTest() {}
 
   /// Modify BDF2 Stepper at end of takeStep.
   virtual void modify(
-    Teuchos::RCP<Thyra::VectorBase<double> > x,
-    const double time, const double dt,
-    const typename Tempus::StepperBDF2ModifierXBase<double>::MODIFIER_TYPE modType)
+      Teuchos::RCP<Thyra::VectorBase<double> > x, const double time,
+      const double dt,
+      const typename Tempus::StepperBDF2ModifierXBase<double>::MODIFIER_TYPE
+          modType)
   {
-    switch(modType) {
-    case StepperBDF2ModifierXBase<double>::X_BEGIN_STEP:
-      {
+    switch (modType) {
+      case StepperBDF2ModifierXBase<double>::X_BEGIN_STEP: {
         testX_BEGIN_STEP = true;
-        testXbegin = get_ele(*(x), 0);
+        testXbegin       = get_ele(*(x), 0);
         break;
       }
-    case StepperBDF2ModifierXBase<double>::X_BEFORE_SOLVE:
-      {
+      case StepperBDF2ModifierXBase<double>::X_BEFORE_SOLVE: {
         testX_BEFORE_SOLVE = true;
-        testDt = dt;
+        testDt             = dt;
         break;
       }
-    case StepperBDF2ModifierXBase<double>::X_AFTER_SOLVE:
-      {
+      case StepperBDF2ModifierXBase<double>::X_AFTER_SOLVE: {
         testX_AFTER_SOLVE = true;
-        testTime = time;
+        testTime          = time;
         break;
       }
-    case StepperBDF2ModifierXBase<double>::X_END_STEP:
-      {
+      case StepperBDF2ModifierXBase<double>::X_END_STEP: {
         testX_END_STEP = true;
-        testXend = get_ele(*(x), 0);
+        testXend       = get_ele(*(x), 0);
         break;
       }
-    default:
-      TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error,
-                                 "Error - unknown action location.\n");
+      default:
+        TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error,
+                                   "Error - unknown action location.\n");
     }
   }
   bool testX_BEGIN_STEP;
@@ -562,7 +574,6 @@ public:
   double testDt;
 };
 
-
 // ************************************************************
 // ************************************************************
 TEUCHOS_UNIT_TEST(BDF2, AppAction_ModifierX)
@@ -578,18 +589,18 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_ModifierX)
   // Setup initial condition SolutionState --------------------
   auto inArgsIC = model->getNominalValues();
   auto icSolution =
-    rcp_const_cast<Thyra::VectorBase<double> > (inArgsIC.get_x());
+      rcp_const_cast<Thyra::VectorBase<double> >(inArgsIC.get_x());
   auto icState = Tempus::createSolutionStateX(icSolution);
-  icState->setTime    (0.0);
-  icState->setIndex   (0);
+  icState->setTime(0.0);
+  icState->setIndex(0);
   icState->setTimeStep(1.0);
-  icState->setOrder   (stepper->getOrder());
+  icState->setOrder(stepper->getOrder());
   icState->setSolutionStatus(Tempus::Status::PASSED);  // ICs are passing.
 
   // Setup TimeStepControl ------------------------------------
   auto timeStepControl = rcp(new Tempus::TimeStepControl<double>());
   timeStepControl->setInitIndex(0);
-  timeStepControl->setInitTime (0.0);
+  timeStepControl->setInitTime(0.0);
   timeStepControl->setFinalTime(2.0);
   timeStepControl->setInitTimeStep(1.0);
   timeStepControl->initialize();
@@ -601,7 +612,6 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_ModifierX)
   solutionHistory->setStorageLimit(3);
   solutionHistory->addState(icState);
 
-
   // Take two time steps (the first step will not test BDF2's modifier)
   stepper->setInitialConditions(solutionHistory);
   solutionHistory->initWorkingState();
@@ -621,12 +631,11 @@ TEUCHOS_UNIT_TEST(BDF2, AppAction_ModifierX)
   auto x = solutionHistory->getCurrentState()->getX();
   TEST_FLOATING_EQUALITY(modifierX->testXbegin, get_ele(*(x), 0), 1.0e-15);
   auto Dt = solutionHistory->getWorkingState()->getTimeStep();
-  x = solutionHistory->getWorkingState()->getX();
+  x       = solutionHistory->getWorkingState()->getX();
   TEST_FLOATING_EQUALITY(modifierX->testXend, get_ele(*(x), 0), 1.0e-15);
   TEST_FLOATING_EQUALITY(modifierX->testDt, Dt, 1.0e-15);
   auto time = solutionHistory->getWorkingState()->getTime();
   TEST_FLOATING_EQUALITY(modifierX->testTime, time, 1.0e-15);
 }
 
-
-} // namespace Tempus_Unit_Test
+}  // namespace Tempus_Unit_Test
